import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { forwardRef, useState } from "react";
import { PropertyLine } from "./propertyLine.js";
import { SyncedSliderLine } from "./syncedSliderLine.js";
import { Color4 } from "@babylonjs/core/Maths/math.color.js";
import { ColorPickerPopup } from "../primitives/colorPicker.js";
/**
 * Reusable component which renders a color property line containing a label, colorPicker popout, and expandable RGBA values
 * The expandable RGBA values are synced sliders that allow the user to modify the color's RGBA values directly
 * @param props - PropertyLine props, replacing children with a color object so that we can properly display the color
 * @returns Component wrapping a colorPicker component with a property line
 */
const ColorPropertyLine = forwardRef((props, ref) => {
    const [color, setColor] = useState(props.value);
    const onSliderChange = (value, key) => {
        let newColor;
        if (key === "a") {
            newColor = Color4.FromColor3(color, value);
        }
        else {
            newColor = color.clone();
            newColor[key] = value / 255;
        }
        setColor(newColor); // Create a new object to trigger re-render
        props.onChange(newColor);
    };
    const onColorPickerChange = (newColor) => {
        setColor(newColor);
        props.onChange(newColor);
    };
    return (_jsx(PropertyLine, { ref: ref, ...props, expandedContent: _jsxs(_Fragment, { children: [_jsx(SyncedSliderLine, { label: "R", value: color.r * 255, min: 0, max: 255, onChange: (value) => onSliderChange(value, "r") }), _jsx(SyncedSliderLine, { label: "G", value: color.g * 255, min: 0, max: 255, onChange: (value) => onSliderChange(value, "g") }), _jsx(SyncedSliderLine, { label: "B", value: color.b * 255, min: 0, max: 255, onChange: (value) => onSliderChange(value, "b") }), color instanceof Color4 && _jsx(SyncedSliderLine, { label: "A", value: color.a, min: 0, max: 1, step: 0.01, onChange: (value) => onSliderChange(value, "a") })] }), children: _jsx(ColorPickerPopup, { ...props, onChange: onColorPickerChange, value: color }) }));
});
export const Color3PropertyLine = ColorPropertyLine;
export const Color4PropertyLine = ColorPropertyLine;
//# sourceMappingURL=colorPropertyLine.js.map