import type { Nullable } from "@babylonjs/core/types.js";
import type { AcceptedDropdownValue, DropdownProps } from "../primitives/dropdown.js";
import type { PropertyLineProps } from "./propertyLine.js";
import type { FunctionComponent } from "react";
type DropdownPropertyLineProps<V extends AcceptedDropdownValue> = Omit<DropdownProps<V>, "includeNullAs"> & PropertyLineProps;
export declare const NullableDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<AcceptedDropdownValue>>;
/**
 * Dropdown component for explicitly defined number values.
 * If value can be undefined, use OptionalNumberDropdownPropertyLine instead.
 * If value can be null, use NullableNumberDropdownPropertyLine instead.
 */
export declare const NumberDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<number>>;
/**
 * Dropdown component for explicitly defined string values.
 * If value can be undefined, use OptionalStringDropdownPropertyLine instead.
 * If value can be null, use NullableStringDropdownPropertyLine instead.
 */
export declare const StringDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<string>>;
/**
 * Dropdown component for Nullable<number> values.
 */
export declare const NullableNumberDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<Nullable<number>>>;
/**
 * Dropdown component for Nullable<string> values.
 */
export declare const NullableStringDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<Nullable<string>>>;
/**
 * Dropdown component for number | undefined values
 */
export declare const OptionalNumberDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<number | undefined>>;
/**
 * Dropdown component for string | undefined values
 */
export declare const OptionalStringDropdownPropertyLine: FunctionComponent<DropdownPropertyLineProps<string | undefined>>;
export {};
