import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from "react";
import { Body1 } from "@fluentui/react-components";
import { PropertyLine } from "./propertyLine.js";
import { SyncedSliderLine } from "./syncedSliderLine.js";
import { Quaternion, Vector4 } from "@babylonjs/core/Maths/math.vector.js";
import { Tools } from "@babylonjs/core/Misc/tools.js";
/**
 * Reusable component which renders a vector property line containing a label, vector value, and expandable XYZW values
 * The expanded section contains a slider/input box for each component of the vector (x, y, z, w)
 * @param props
 * @returns
 */
const TensorPropertyLine = (props) => {
    const converted = (val) => (props.valueConverter ? props.valueConverter.from(val) : val);
    const formatted = (val) => converted(val).toFixed(2);
    const [vector, setVector] = useState(props.value);
    const { min, max } = props;
    const onChange = (val, key) => {
        const value = props.valueConverter ? props.valueConverter.to(val) : val;
        const newVector = vector.clone();
        newVector[key] = value; // The syncedSlider for 'w' is only rendered when vector is a Vector4, so this is safe
        setVector(newVector);
        props.onChange(newVector);
    };
    return (_jsx(PropertyLine, { ...props, expandedContent: _jsxs(_Fragment, { children: [_jsx(SyncedSliderLine, { label: "X", value: converted(vector.x), min: min, max: max, onChange: (val) => onChange(val, "x") }), _jsx(SyncedSliderLine, { label: "Y", value: converted(vector.y), min: min, max: max, onChange: (val) => onChange(val, "y") }), _jsx(SyncedSliderLine, { label: "Z", value: converted(vector.z), min: min, max: max, onChange: (val) => onChange(val, "z") }), vector instanceof Vector4 && _jsx(SyncedSliderLine, { label: "W", value: vector.w, min: min, max: max, onChange: (val) => onChange(val, "w") })] }), children: _jsx(Body1, { children: `X: ${formatted(props.value.x)} | Y: ${formatted(props.value.y)} | Z: ${formatted(props.value.z)}${props.value instanceof Vector4 ? ` | W: ${formatted(props.value.w)}` : ""}` }) }));
};
const ToDegreesConverter = { from: Tools.ToDegrees, to: Tools.ToRadians };
export const RotationVectorPropertyLine = (props) => {
    const min = props.useDegrees ? 0 : undefined;
    const max = props.useDegrees ? 360 : undefined;
    return _jsx(Vector3PropertyLine, { ...props, valueConverter: props.useDegrees ? ToDegreesConverter : undefined, min: min, max: max });
};
const QuaternionPropertyLineInternal = TensorPropertyLine;
export const QuaternionPropertyLine = (props) => {
    const min = props.useDegrees ? 0 : undefined;
    const max = props.useDegrees ? 360 : undefined;
    const [quat, setQuat] = useState(props.value);
    const onQuatChange = (val) => {
        setQuat(val);
        props.onChange(val);
    };
    const onEulerChange = (val) => {
        const quat = Quaternion.FromEulerAngles(val.x, val.y, val.z);
        setQuat(quat);
        props.onChange(quat);
    };
    return props.useDegrees ? (_jsx(Vector3PropertyLine, { ...props, value: quat.toEulerAngles(), valueConverter: ToDegreesConverter, min: min, max: max, onChange: onEulerChange })) : (_jsx(QuaternionPropertyLineInternal, { ...props, value: quat, min: min, max: max, onChange: onQuatChange }));
};
export const Vector3PropertyLine = TensorPropertyLine;
export const Vector4PropertyLine = TensorPropertyLine;
//# sourceMappingURL=vectorPropertyLine.js.map