import { jsx as _jsx } from "react/jsx-runtime";
import { useEffect, useState } from "react";
import { Input as FluentInput, makeStyles } from "@fluentui/react-components";
const useInputStyles = makeStyles({
    text: {
        height: "auto",
        textAlign: "right",
    },
    float: {
        height: "auto",
        width: "80px", // Fixed width for number input
        flexShrink: 0,
    },
});
/**
 * This is an input text box that stops propagation of change events and sets its width based on the type of input (text or number)
 * @param props
 * @returns
 */
export const Input = (props) => {
    const classes = useInputStyles();
    const [value, setValue] = useState(props.value ?? "");
    const type = typeof props.value === "number" ? "number" : "text";
    useEffect(() => {
        setValue(props.value ?? ""); // Update local state when props.value changes
    }, [props.value]);
    const handleChange = (event, _) => {
        event.stopPropagation(); // Prevent event propagation
        const value = type === "number" ? Number(event.target.value) : String(event.target.value);
        props.onChange(value); // Call the original onChange handler passed as prop
        setValue(value); // Update local state with the new value
    };
    const handleKeyDown = (event) => {
        event.stopPropagation(); // Prevent event propagation
    };
    return (_jsx(FluentInput, { ...props, type: type, size: "small", value: value.toString(), className: typeof props.value === "number" ? classes.float : classes.text, onChange: handleChange, onKeyDown: handleKeyDown }));
};
//# sourceMappingURL=input.js.map